VerbHandler class abstract

Constructors

VerbHandler()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept(String command) → bool
Returns true if a verb handler can accept this command. @param command - at protocol command @returns bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(String command, InboundConnection inboundConnection) → Future<void>
Processes a given command from a inboundConnection @param command - at protocol command @param inboundConnection - requesting InboundConnection
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited