Info class

The "info" verb returns a JSON object as follows:

{
  "version" : "the version being run",
  "uptimeAsWords" : "uptime as string: D days, H hours, M minutes, S seconds",
  "features" : [
    {
      "name" : "ID of feature 1",
      "status" : "One of Preview, Beta, GA",
      "description" : "Description of feature"
    },
    {
      "name" : "ID of feature 2",
      "status" : "One of Preview, Beta, GA",
      "description" : "Description of feature"
    },
    ...
  ]
}

info:brief will just return the version and uptime as milliseconds

{
  "version" : "the version being run",
  "uptimeAsMillis" : "uptime in milliseconds, as integer",
}

This verb does not require authentication.

Syntax: info

Inheritance

Constructors

Info()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependsOn() → Verb?
Returns name of the Verb this verb depends on
override
name() → String
Returns name of the verb
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiresAuth() → bool
Returns whether a verb requires authentication
override
syntax() → String
Returns syntax of the verb in a regular expression format
override
toString() → String
A string representation of this object.
inherited
usage() → String
Returns a sample usage of the Verb
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited