LocalLookup class

The "llookup" verb can be used to locally lookup keys stored on the secondary server. To perform local look up, the user should be successfully authenticated using cram/pkam verb. A malformed request closes the @sign client connection. Syntax: llookup:

Inheritance

Constructors

LocalLookup()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependsOn() → Verb?
Returns name of the Verb this verb depends on
override
name() → String
Returns name of the verb
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiresAuth() → bool
Returns whether a verb requires authentication
override
syntax() → String
Returns syntax of the verb in a regular expression format
override
toString() → String
A string representation of this object.
inherited
usage() → String
Returns a sample usage of the Verb
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited