Monitor class

Monitor verb is used to stream incoming connections from the secondary server to the client. The “monitor:” verb is used to monitor either all or specific notification events that are sent using the “notify:” verb. Optionally pass a regex to stream only notifications that match the regex. e.g. monitor or monitor .wavi

Inheritance

Constructors

Monitor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependsOn() → Verb?
Returns name of the Verb this verb depends on
override
name() → String
Returns name of the verb
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiresAuth() → bool
Returns whether a verb requires authentication
override
syntax() → String
Returns syntax of the verb in a regular expression format
override
toString() → String
A string representation of this object.
inherited
usage() → String
Returns a sample usage of the Verb
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited