Notify class

The “notify” verb allows to notify the another @sign. The @sign should be authenticated using the cram/pkam verb prior to use the notify verb. A malformed request does not close the @sign client connection.

Syntax: notify:notifier:

Inheritance

Constructors

Notify()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependsOn() → Verb?
Returns name of the Verb this verb depends on
override
name() → String
Returns name of the verb
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiresAuth() → bool
Returns whether a verb requires authentication
override
syntax() → String
Returns syntax of the verb in a regular expression format
override
toString() → String
A string representation of this object.
inherited
usage() → String
Returns a sample usage of the Verb
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited