Pkam class

The pkam( Public Key Authentication Mechanism) verb is used to authenticate the @sign to the secondary server. This is similar to how ssh authentication works. On successful request, binds the @sign to the secondary server. On successful pkam verb request, the @sign is successfully authenticated to the secondary server and allows user to Add/Update, Delete and lookup the keys in their respective secondary servers.

Syntax: pkam:

Inheritance

Constructors

Pkam()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependsOn() → Verb
Returns name of the Verb this verb depends on
override
name() → String
Returns name of the verb
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiresAuth() → bool
Returns whether a verb requires authentication
override
syntax() → String
Returns syntax of the verb in a regular expression format
override
toString() → String
A string representation of this object.
inherited
usage() → String
Returns a sample usage of the Verb
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited