Stats class

stats verb used to get all the available metrics Syntax: stats example: Number of active inbound/outbound connections, last commit ID etc. These are the available metrics '1' - Number of active inbound connections '2' - Number of active outbound connections '3' - Last Commit Id '4' - Total Secondary storage size '5' - Most Visited AtSign '6' - Most Visited AtKeys '7' - Secondary Server Version, '8' - Last log in date time, '9' - Total Disk Size '10' - Last login datetime with PKAM '11' - Notification count Syntax: stats - List all the available metrics We can provide specific metrics id's as a comma separated list e.g. stats:1,2,3 stats:10

Inheritance

Constructors

Stats()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dependsOn() → Verb?
Returns name of the Verb this verb depends on
override
name() → String
Returns name of the verb
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requiresAuth() → bool
Returns whether a verb requires authentication
override
syntax() → String
Returns syntax of the verb in a regular expression format
override
toString() → String
A string representation of this object.
inherited
usage() → String
Returns a sample usage of the Verb
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited