AtSecondaryServer class abstract
Represents the secondary server of the @protocol. Contains methods to start, stop and server the requests.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMetrics(
) → ConnectionMetrics - Returns various connection metrics
-
isRunning(
) → bool -
Returns status of the server
@return true is the server is running.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void -
Pauses the server. In this state the server would have been fully initialized but it will not serve any request till the resume is
called.
inherited
-
resume(
) → void -
Resumes the server. In this state the server will be able to serve the request.
inherited
-
setExecutor(
VerbExecutor executor) → void - Sets the executor for the requests to the server
-
setServerContext(
AtServerContext context) → void - Sets the server context @param context - context for this server to start
-
setVerbHandlerManager(
VerbHandlerManager handlerManager) → void - Sets Verb handler to be used by the server
-
start(
) → void -
Starts the server. Calling this method on an already started server has no effect.
@throws
AtServerExceptionif the server cannot be startedinherited -
stop(
) → Future< void> -
Stops the server. Calling this method on an already stopped server has no effect.
@throws
AtServerExceptionif the server cannot be stoppedinherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited